==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Haber paylaşımı başarısız: girdiğiniz sunucu çözülemedi veya hiç bir haber sunmuyor.',
	'avis_echec_syndication_02' => 'Haber paylaşımı başarısız: bu sitenin sunucusuna ulaşılamadı.',
	'avis_site_introuvable' => 'Site bulunamadı',
	'avis_site_syndique_probleme' => 'Dikkat : bu site ile paylaşımda sorun çıktı ; sistem geçici bir süre için durduruldu. Bu sitenin paylaşım dosyasının adresini kontrol edin (<b>@url_syndic@</b>) ve bilgileri yeniden almayı deneyin.',
	'avis_sites_probleme_syndication' => 'Bu siteler paylaşım işleminde sorunla karşılaştı',
	'avis_sites_syndiques_probleme' => 'Haber paylaşımlı şu sitelerde sorun çıktı',

	// B
	'bouton_radio_modere_posteriori' => 'sonradan onayla yönetim', # MODIF
	'bouton_radio_modere_priori' => 'önceden onayla yönetim', # MODIF
	'bouton_radio_non_syndication' => 'Paylaşım (syndication) yok',
	'bouton_radio_syndication' => 'Paylaşım :',

	// E
	'entree_adresse_fichier_syndication' => 'Paylaşım dosyasının adresi :',
	'entree_adresse_site' => '<b>Site adresi</b> [Zorunlu]',
	'entree_description_site' => 'Sitenin tanımı',

	// F
	'form_prop_nom_site' => 'Sitenin ismi',

	// I
	'icone_modifier_site' => 'Bu siteyi değiştir',
	'icone_referencer_nouveau_site' => 'Yeni bir siteye atıfta bulun',
	'icone_voir_sites_references' => 'Atıfta bulunulan siteleri göster',
	'info_a_valider' => '[onaylanacak]',
	'info_bloquer' => 'engelle',
	'info_bloquer_lien' => 'bu bağlantıyı engelle',
	'info_derniere_syndication' => 'Bu sitenin son paylaşım tarihi:',
	'info_liens_syndiques_1' => 'paylaşılan bağlar :',
	'info_liens_syndiques_2' => 'Onay bekliyor.',
	'info_nom_site_2' => '<b>Site adı</b> [zorunlu]',
	'info_panne_site_syndique' => 'Paylaşımlı sitede arıza var',
	'info_probleme_grave' => 'sorun',
	'info_question_proposer_site' => 'Kim atıfta bulunulan siteler önerebilir ?',
	'info_retablir_lien' => 'Bu bağlantıyı tekrar kur',
	'info_site_attente' => 'Onaylanmayı bekleyen Web sitesi',
	'info_site_propose' => 'Sitenin önerildiği tarih :',
	'info_site_reference' => 'Atıfta bulunulan çevrimiçi site',
	'info_site_refuse' => 'Web sitesi reddedildi',
	'info_site_syndique' => 'Bu site paylaşımlıdır...', # MODIF
	'info_site_valider' => 'Onaylanacak siteler',
	'info_sites_referencer' => 'Bir siteye atıfta bulun',
	'info_sites_refuses' => 'Reddedilen siteler',
	'info_statut_site_1' => 'Bu site :',
	'info_statut_site_2' => 'Yayınlandı',
	'info_statut_site_3' => 'Önerildi',
	'info_statut_site_4' => 'Çöp kutusuna', # MODIF
	'info_syndication' => 'Paylaşım :',
	'info_syndication_articles' => 'Makale',
	'item_bloquer_liens_syndiques' => 'Paylaşımlı bağların onay için engellenmesi',
	'item_gerer_annuaire_site_web' => 'Bir Web siteleri rehberini yönet',
	'item_non_bloquer_liens_syndiques' => 'Paylaşmadan gelen bağları engelleme',
	'item_non_gerer_annuaire_site_web' => 'Web siteleri dizinini iptal et.',
	'item_non_utiliser_syndication' => 'Otomatik paylaşımı kullanma',
	'item_utiliser_syndication' => 'Otomatik paylaşımı kullan',

	// L
	'lien_mise_a_jour_syndication' => 'Şimdi güncelle',
	'lien_nouvelle_recuperation' => 'Verilerin yeniden alınmasını dene',

	// S
	'syndic_choix_moderation' => 'Bu siteden ileride gelecek bağları ne yapmalı ?',
	'syndic_choix_oublier' => 'Paylaşım dosyasında artık bulunmayan bağları ne yapmalı ?',
	'syndic_choix_resume' => 'Bazı siteler makalelerin tüm içeriğini yayınlarlar. Bu durumdaki sitelerin listesini yayınlamak ister misiniz :',
	'syndic_lien_obsolete' => 'ölü bağ',
	'syndic_option_miroir' => 'hepsini otomatik olarak engelle',
	'syndic_option_oubli' => 'hepsini sil (@mois@ mois’dan sonra)',
	'syndic_option_resume_non' => 'makalelerin tüm içeriği (HTML formatında)',
	'syndic_option_resume_oui' => 'kısa bir özet (metin formatında)',
	'syndic_options' => 'Paylaşım seçenekleri :',

	// T
	'texte_liens_sites_syndiques' => 'Paylaşımlı sitelerden gelen bağlar önceden engellenebilir ; aşağıdaki ayarlama yaratılmalarından sonra paylaşılan sitelerin varsayılan ayarlarını gösterir. Sonradan her bir bağın engelini tek tek kaldırmak ya da her site için gelecekteki bağları engellemeyi tek tek seçmek olanaklıdır.', # MODIF
	'texte_messages_publics' => 'Makalenin kamu mesajları : ',
	'texte_non_fonction_referencement' => 'Bu otomatik işlevi kullanmamayı tercih edebilir, bu siteyle ilgili unsurları kendiniz belirtebilirsiniz.... ', # MODIF
	'texte_referencement_automatique' => '<b>Otomatik site referansı</b><br /> Aşağıya URL adresini ya da paylaşım dosyasının adresini belirterek bir Web sitesine hızla atıfta bulunabilirsiniz. SPIP otomatik olarak bu siteyle ilgili bilgileri toplayacaktır (başlık, tanımlama...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Kaydetmeden önce <tt>@url@</tt> tarafından sağlanan bilgileri doğrulayınız.',
	'texte_syndication' => 'Bir Web sitesinin izin vermesi halinde yeniliklerinin listesini otomatik olarak listelemek olasıdır. Bunun için paylaşımı çalıştırmanız gerekir. Bazı servis sağlayıcılar bu işlevi engeller; böyle bir durumda, içerik paylaşımını kendi sitenizden kullanamazsınız.', # MODIF
	'titre_articles_syndiques' => 'Bu siteden alınan paylaşımlı makaleler',
	'titre_dernier_article_syndique' => 'Son yayınlanan paylaşımlı makaleler',
	'titre_page_sites_tous' => 'Atıfta bulunulan siteler ',
	'titre_referencement_sites' => 'Sitelere atıf ve paylaşım',
	'titre_site_numero' => 'SİTE NO :',
	'titre_sites_proposes' => 'Önerilen siteler',
	'titre_sites_references_rubrique' => 'Bu bölümde atıfta bulunulan siteler ',
	'titre_sites_syndiques' => 'Paylaşımlı siteler',
	'titre_sites_tous' => 'Atıfta bulunulan siteler ',
	'titre_syndication' => 'Site paylaşımı'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Haber paylaşımı başarısız: girdiğiniz sunucu çözülemedi veya hiç bir haber sunmuyor.',
	'avis_echec_syndication_02' => 'Haber paylaşımı başarısız: bu sitenin sunucusuna ulaşılamadı.',
	'avis_site_introuvable' => 'Site bulunamadı',
	'avis_site_syndique_probleme' => 'Dikkat : bu site ile paylaşımda sorun çıktı ; sistem geçici bir süre için durduruldu. Bu sitenin paylaşım dosyasının adresini kontrol edin (<b>@url_syndic@</b>) ve bilgileri yeniden almayı deneyin.',
	'avis_sites_probleme_syndication' => 'Bu siteler paylaşım işleminde sorunla karşılaştı',
	'avis_sites_syndiques_probleme' => 'Haber paylaşımlı şu sitelerde sorun çıktı',

	// B
	'bouton_radio_modere_posteriori' => 'sonradan onayla yönetim', # MODIF
	'bouton_radio_modere_priori' => 'önceden onayla yönetim', # MODIF
	'bouton_radio_non_syndication' => 'Paylaşım (syndication) yok',
	'bouton_radio_syndication' => 'Paylaşım :',

	// E
	'entree_adresse_fichier_syndication' => 'Paylaşım dosyasının adresi :',
	'entree_adresse_site' => '<b>Site adresi</b> [Zorunlu]',
	'entree_description_site' => 'Sitenin tanımı',

	// F
	'form_prop_nom_site' => 'Sitenin ismi',

	// I
	'icone_modifier_site' => 'Bu siteyi değiştir',
	'icone_referencer_nouveau_site' => 'Yeni bir siteye atıfta bulun',
	'icone_voir_sites_references' => 'Atıfta bulunulan siteleri göster',
	'info_1_site' => '1 site',
	'info_a_valider' => '[onaylanacak]',
	'info_bloquer' => 'engelle',
	'info_bloquer_lien' => 'bu bağlantıyı engelle',
	'info_derniere_syndication' => 'Bu sitenin son paylaşım tarihi:',
	'info_liens_syndiques_1' => 'paylaşılan bağlar :',
	'info_liens_syndiques_2' => 'Onay bekliyor.',
	'info_nom_site_2' => '<b>Site adı</b> [zorunlu]',
	'info_panne_site_syndique' => 'Paylaşımlı sitede arıza var',
	'info_probleme_grave' => 'sorun',
	'info_question_proposer_site' => 'Kim atıfta bulunulan siteler önerebilir ?',
	'info_retablir_lien' => 'Bu bağlantıyı tekrar kur',
	'info_site_attente' => 'Onaylanmayı bekleyen Web sitesi',
	'info_site_propose' => 'Sitenin önerildiği tarih :',
	'info_site_reference' => 'Atıfta bulunulan çevrimiçi site',
	'info_site_refuse' => 'Web sitesi reddedildi',
	'info_site_syndique' => 'Bu site paylaşımlıdır...', # MODIF
	'info_site_valider' => 'Onaylanacak siteler',
	'info_sites_referencer' => 'Bir siteye atıfta bulun',
	'info_sites_refuses' => 'Reddedilen siteler',
	'info_statut_site_1' => 'Bu site :',
	'info_statut_site_2' => 'Yayınlandı',
	'info_statut_site_3' => 'Önerildi',
	'info_statut_site_4' => 'Çöp kutusuna', # MODIF
	'info_syndication' => 'Paylaşım :',
	'info_syndication_articles' => 'Makale',
	'item_bloquer_liens_syndiques' => 'Paylaşımlı bağların onay için engellenmesi',
	'item_gerer_annuaire_site_web' => 'Bir Web siteleri rehberini yönet',
	'item_non_bloquer_liens_syndiques' => 'Paylaşmadan gelen bağları engelleme',
	'item_non_gerer_annuaire_site_web' => 'Web siteleri dizinini iptal et.',
	'item_non_utiliser_syndication' => 'Otomatik paylaşımı kullanma',
	'item_utiliser_syndication' => 'Otomatik paylaşımı kullan',

	// L
	'lien_mise_a_jour_syndication' => 'Şimdi güncelle',
	'lien_nouvelle_recuperation' => 'Verilerin yeniden alınmasını dene',

	// S
	'syndic_choix_moderation' => 'Bu siteden ileride gelecek bağları ne yapmalı ?',
	'syndic_choix_oublier' => 'Paylaşım dosyasında artık bulunmayan bağları ne yapmalı ?',
	'syndic_choix_resume' => 'Bazı siteler makalelerin tüm içeriğini yayınlarlar. Bu durumdaki sitelerin listesini yayınlamak ister misiniz :',
	'syndic_lien_obsolete' => 'ölü bağ',
	'syndic_option_miroir' => 'hepsini otomatik olarak engelle',
	'syndic_option_oubli' => 'hepsini sil (@mois@ mois’dan sonra)',
	'syndic_option_resume_non' => 'makalelerin tüm içeriği (HTML formatında)',
	'syndic_option_resume_oui' => 'kısa bir özet (metin formatında)',
	'syndic_options' => 'Paylaşım seçenekleri :',

	// T
	'texte_liens_sites_syndiques' => 'Paylaşımlı sitelerden gelen bağlar önceden engellenebilir ; aşağıdaki ayarlama yaratılmalarından sonra paylaşılan sitelerin varsayılan ayarlarını gösterir. Sonradan her bir bağın engelini tek tek kaldırmak ya da her site için gelecekteki bağları engellemeyi tek tek seçmek olanaklıdır.', # MODIF
	'texte_messages_publics' => 'Makalenin kamu mesajları : ',
	'texte_non_fonction_referencement' => 'Bu otomatik işlevi kullanmamayı tercih edebilir, bu siteyle ilgili unsurları kendiniz belirtebilirsiniz.... ', # MODIF
	'texte_referencement_automatique' => '<b>Otomatik site referansı</b><br /> Aşağıya URL adresini ya da paylaşım dosyasının adresini belirterek bir Web sitesine hızla atıfta bulunabilirsiniz. SPIP otomatik olarak bu siteyle ilgili bilgileri toplayacaktır (başlık, tanımlama...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Kaydetmeden önce <tt>@url@</tt> tarafından sağlanan bilgileri doğrulayınız.',
	'texte_syndication' => 'Bir Web sitesinin izin vermesi halinde yeniliklerinin listesini otomatik olarak listelemek olasıdır. Bunun için paylaşımı çalıştırmanız gerekir. Bazı servis sağlayıcılar bu işlevi engeller; böyle bir durumda, içerik paylaşımını kendi sitenizden kullanamazsınız.', # MODIF
	'titre_articles_syndiques' => 'Bu siteden alınan paylaşımlı makaleler',
	'titre_dernier_article_syndique' => 'Son yayınlanan paylaşımlı makaleler',
	'titre_page_sites_tous' => 'Atıfta bulunulan siteler ',
	'titre_referencement_sites' => 'Sitelere atıf ve paylaşım',
	'titre_site_numero' => 'SİTE NO :',
	'titre_sites_proposes' => 'Önerilen siteler',
	'titre_sites_references_rubrique' => 'Bu bölümde atıfta bulunulan siteler ',
	'titre_sites_syndiques' => 'Paylaşımlı siteler',
	'titre_sites_tous' => 'Atıfta bulunulan siteler ',
	'titre_syndication' => 'Site paylaşımı'
);

?>
